import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleLinear,
  max,
  format,
  extent
} from 'd3';
import { message } from './message.js';
import { useData } from './useData.js';
import { AxisBottom } from './AxisBottom.js';
import { AxisLeft } from './AxisLeft.js';
import { Marks } from './Marks.js';

const csvUrl =
  'https://gist.githubusercontent.com/netj/8836201/raw/6f9306ad21398ea43cba4f7d537619d0e07d5ae3/iris.csv';
const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 20,
  bottom: 40,
  left: 200,
};

const App = () => {
  const data = useData();
  const innerHeight =
    height - margin.top - margin.bottom;
  const innerWidth =
    width - margin.left - margin.right;

  if (!data) {
    return <pre>Loading ... </pre>;
  }

  const xAxisTickFormat = (n) =>
    format('.2s')(n).replace('G', 'B');
  const yValue = (d) => d['sepal.length'];
  const xValue = (d) => d['sepal.width'];
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([0, innerHeight])
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
        />
        <AxisLeft yScale={yScale} innerWidth={innerWidth}/>
        <text
          className="axis-label"
          x={innerWidth / 2}
        >
          Population
        </text>
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
        />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById(
  'root'
);
ReactDOM.render(<App />, rootElement);
